# baangt-MvCrrspXLS

Move-Corresponding implementation for Excel-Sheets/Tabs.

# Functionality

Append lines from Excel sheets/tabs to another excel sheet/tab for those columns, that have
idential names. Optional: Add missing columns to destination file.


